/* NickServ help texts */

static const char *ns_help[] = {
"\2NickServ\2 allows you to \"register\" a nickname and",
"prevent others from using them.  If the nick is not used",
"for 30 days, the registration will expire.  The following",
"commands allow for registration and maintenance of",
"nicknames; to use them, type \2/msg NickServ <command>\2.",
"For more information on a specific command, type",
"\2/msg NickServ help <command>\2.",
" ",
"    REGISTER   Register a nickname",
"    IDENTIFY   Identify yourself with your password",
"    ACCESS     Modify the list of authorized addresses",
"    SET        Set options, including kill protection",
"    DROP       Cancel the registration of a nickname",
"    RECOVER    Kill another user who has taken your nick",
"    RELEASE    Regain custody of your nick after RECOVER",
" ",
"Other commands: GHOST, INFO, LIST",
" ",
"\2NOTICE:\2 This service is intended to provide a way for",
"IRC users to ensure their identity is not compromised.",
"It is \2NOT\2 intended to facilitate \"stealing\" of",
"nicknames or other malicious actions.  Abuse of NickServ",
"will result in, at minimum, loss of the abused",
"nickname(s).",
NULL
};

static const char *register_help[] = {
"Syntax: \2REGISTER \37password\37\2",
" ",
"Registers your nickname in the NickServ database.  Once",
"your nick is registered, you can use the \2SET\2 and \2ACCESS\2",
"commands to configure your nick's settings as you like",
"them.  Make sure you remember the password you use when",
"registering - you'll need it to make changes to your nick",
"later.  (Note that \2case matters!\2  \37FIDO\37, \37Fido\37, and \37 fido\37",
"are all different passwords!)",
" ",
"Guidelines on choosing passwords:",
" ",
"Passwords should not be easily guessable.  For example,",
"using your real name as a password is a bad idea.  Using",
"your nickname as a password is a much worse idea ;) and,",
"in fact, NickServ will not allow it.  Also, short",
"passwords are vulnerable to trial-and-error searches, so",
"you should choose a password at least 5 characters long.",
"Finally, the space character cannot be used in passwords.",
NULL
};

static const char *identify_help[] = {
"Syntax: \2IDENTIFY \37password\37\2",
" ",
"Tells NickServ that you are really the owner of this",
"nick.  Many commands require you to authenticate yourself",
"with this command before you use them.  The password",
"should be the same one you sent with the \2REGISTER\2",
"command.",
NULL
};

static const char *drop_help[] = {
"Syntax: \2DROP\2",
" ",
"Drops your nickname from the NickServ database.  A nick",
"that has been dropped is free for anyone to re-register.",
" ",
"In order to use this command, you must first identify",
"with your password (\2/msg NickServ HELP IDENTIFY\2 for more",
"information).",
NULL
};

static const char *oper_drop_help[] = {
"Syntax: \2DROP [\37nickname\37]\2",
" ",
"Without a parameter, drops your nickname from the",
"NickServ database.  With a parameter, drops the named",
"nick from the database.",
NULL
};

static const char *info_help[] = {
"Syntax: \2INFO \37nickname\37\2",
" ",
"Displays information about the given nickname, such as",
"the nick's owner, last seen address and time, and nick",
"options.",
NULL
};

static const char *set_help[] = {
"Syntax: \2SET \37option\37 \37parameters\37\2",
" ",
"Sets various nickname options.  \37option\37 can be one of:",
" ",
"    KILL       Turn kill protection on or off",
"    PASSWORD   Set your nickname password",
" ",
"In order to use this command, you must first identify",
"with your password (\2/msg NickServ HELP IDENTIFY\2 for more",
"information).",
NULL
};

static const char *set_kill_help[] = {
"Syntax: \2SET KILL {ON|OFF}\2",
" ",
"Turns the automatic kill protection option for your nick",
"on or off.  With kill protection on, if another user",
"tries to take your nick, they will be given one minute to",
"change to another nick, after which they will be forcibly",
"removed from IRC by NickServ.",
NULL
};

static const char *set_pass_help[] = {
"Syntax: \2SET PASSWORD \37new-password\37\2",
" ",
"Changes the password used to identify you as the nick's",
"owner.",
NULL
};

static const char *recover_help[] = {
"Syntax: \2RECOVER \37nickname\37\2"
" ",
"Allows you to recover your nickname if someone else has",
"taken it; this does the same thing that NickServ does",
"automatically if someone steals a kill-protected nick.",
" ",
"When you give this command, NickServ will bring a fake",
"user online with the same nickname as the user you're",
"trying to recover your nick from.  This causes the IRC",
"servers to disconnect the other user.  NickServ's fake",
"user will remain online for one minute to ensure that the",
"other user does not immediately reconnect; after that",
"minute, you can reclaim your nick.  Alternatively, use",
"the \2RELEASE\2 command (\2/msg NickServ HELP RELEASE\2) to get",
"the nick back sooner.",
" ",
"In order to use the RECOVER command for a nick, your",
"current address as shown in /WHOIS must be on that nick's",
"access list.",
NULL
};

static const char *release_help[] = {
"Syntax: \2RELEASE \37nickname\37\2"
"Instructs NickServ to remove any hold on your nickname",
"caused by automatic kill protection or use of the \2RECOVER\2",
"command.  By default, such holds last for one minute;",
"this command gets rid of them sooner.",
" ",
"In order to use the RELEASE command for a nick, your",
"current address as shown in /WHOIS must be on that nick's",
"access list.",
NULL
};

static const char *ghost_help[] = {
"Syntax: \2GHOST \37nickname\37\2",
" ",
"Terminates a \"ghost\" IRC session using your nick.  A",
"\"ghost\" session is one which is not actually connected,",
"but which the IRC server believes is still online for one",
"reason or another.  Typically, this happens if your",
"computer crashes or your Internet or modem connection",
"goes down for a short period of time while you're on IRC.",
" ",
"In order to use the GHOST command for a nick, your",
"current address as shown in /WHOIS must be on that nick's",
"access list.",
NULL
};

static const char *list_help[] = {
"Syntax: \2LIST \37pattern\37\2",
" ",
"Lists all registered nicknames which match the given",
"pattern, in \37nick!user@host\37 format."
" ",
"Examples:",
" ",
"    \2LIST *!joeuser@foo.com\2",
"        Lists all nicks owned by joeuser@foo.com.",
" ",
"    \2LIST *Bot*!*\2",
"        Lists all registered nicks with \2Bot\2 in their",
"        names (case insensitive).",
" ",
"    \2LIST *!*@*.bar.org\2",
"        Lists all nicks owned by users in the \2bar.org\2",
"        domain.",
NULL
};

static const char *access_help[] = {
"Syntax: \2ACCESS ADD \37mask\37\2",
"        \2ACCESS DEL \37mask\37\2",
"        \2ACCESS LIST\2",
" ",
"Modifies or displays the access list for your nick.  This",
"is the list of addresses which will be automatically",
"recognized by NickServ as allowed to use the nick.  If",
"you want to use the nick from a different address, you",
"need to send an \2IDENTIFY\2 command to make NickServ",
"recognize you.",
" ",
"Examples:",
" ",
"    \2ACCESS ADD achurch@*.dragonfire.net\2",
"        Allows access to user \2achurch\2 from any machine in",
"        the \2dragonfire.net\2 domain.",
" ",
"    \2ACCESS DEL achurch@*.dragonfire.net\2",
"        Reverses the previous command.",
" ",
"    \2ACCESS LIST",
"        Displays the current access list.",
NULL
};

static const char *getpass_help[] = {
"Syntax: \2GETPASS \37nickname\37\2",
" ",
"Returns the password for the given nickname.  \2Note that\2",
"\2whenever this command is used, a message including the\2",
"\2person who issued the command and the nickname it was\2",
"\2used on will be logged and sent out as a WALLOPS.\2",
NULL
};
